"pbern" <-

function(q, prob, lower.tail=TRUE, log.p = FALSE)



{



	pbinom(q,size=1,prob=prob,lower.tail=lower.tail,log.p=log.p)

	

}

